package org.greenstone.gatherer.checklist;

import javax.swing.JCheckBox;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.msm.MetadataSet;
import org.greenstone.gatherer.msm.MSMUtils;
import org.greenstone.gatherer.util.Utility;
import org.w3c.dom.Element;
/** An Entry encapsulates a single row of the list, both its check box and the object the row represents. */
public class Entry
    extends JCheckBox 
    implements Comparable {

    /** Is this checkboxes state fixed. */
    protected boolean fixed = false;
    /** The original object this row is based on, and whose toString() is used to generate the check box label. */
    protected Object object = null;
    /** A sundry string for storing original values (rather than strings retrieved from dictionary). */
    protected String property;
    /** Constructor. */
    public Entry(Object object) {
	super(object.toString());
	this.object = object;
	// We also build a special tool tip for metadata sets.
	if(object instanceof MetadataSet) {
	    MetadataSet set = (MetadataSet) object;
				// Build tooltip
	    StringBuffer tip = new StringBuffer(Gatherer.dictionary.get("NewCollectionPrompt.Set_Contains"));
	    tip.append(":\n");
	    for(int i = 0; i < set.size(); i++) {
		Element element = set.getElement(i);
		tip.append(MSMUtils.getIdentifier(element));
		if(i < set.size() - 1) {
		    tip.append(", ");
		}
	    }
	    setToolTipText(Utility.formatHTMLWidth(tip.toString(), 60));
	}
    }

    /** Constructor. */
    public Entry(String text, boolean is_selected) {
	super(text);
	setSelected(is_selected);
    }

    /** Test this Entry against an Object for ordering. 
     * @param obj the other Object.
     * @return <0, 0 or >0 if this Entry is before, equal to or after the given object.
     */
    public int compareTo(Object obj) {
	return toString().toLowerCase().compareTo(obj.toString().toLowerCase());
    }
    /** Test this Entry against an Object for equality. 
     * @param obj the other Object.
     * @return true if the two are equal, false otherwise.
     */
    public boolean equals(Object obj) {
	return toString().equalsIgnoreCase(obj.toString());
    }

    /** Retrieve the object associated with this entry.
	  * @return An <strong>Object</strong>.
	  */
    public Object getObject() {
	if(object == null) {
	    return getText();
	}
	return object;
    }

    public String getProperty() {
	return property;
    }

    public boolean isFixed() {
	return fixed;
    }

    public void setFixed(boolean fixed) {
	this.fixed = fixed;
    }

    public void setProperty(String property) {
	this.property = property;
    }

    public String toString() {
	if(object == null) {
	    return getText();
	}
	return object.toString();
    }
}
