/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.help;

import java.io.*;
import java.util.HashMap;
import javax.swing.tree.DefaultTreeModel;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.cdm.CommandTokenizer;
import org.greenstone.gatherer.help.HelpItem;
import org.greenstone.gatherer.util.Utility;
/** This is a hardcoded tree model which serves as the help pages contents page. 
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.3
 */
public class ContentModel
    extends DefaultTreeModel {
    /** Constructor that builds the contents model. 
     * @see org.greenstone.gatherer.help.HelpItem
     */
    public ContentModel() {
	super(new HelpItem("Contents"));
	// Load the contents file and build the contents structure found within.
	try {
	    FileReader file_reader = new FileReader(Utility.HELP_DIR + "index.txt");
	    BufferedReader buffered_reader = new BufferedReader(file_reader);
	    String line = null;
	    HashMap known_entries = new HashMap();
	    while((line = buffered_reader.readLine()) != null) {
		// We'll use my ever popular command tokenizer to ensure we can parse index | title.
		CommandTokenizer tokenizer = new CommandTokenizer(line);
		// The first thing off the tokenizer is an index of the form xx.xx.xx
		String index_str = tokenizer.nextToken();
		// And the second is a title for this entry
		String title = tokenizer.nextToken();
		// Now we determine the parent of this entry. In general this involves removing the last portion of the index so 2.3 becomes 2. However there is a special case when the index has only one part, ie 2, in which case it get added to the root, then the index is replaced with 2.0.
		int position = -1;
		if((position = index_str.lastIndexOf(".")) != -1) {
		    // Find parent index
		    String parent_index = index_str.substring(0, position);
		    // Retrieve parent item
		    HelpItem parent_item = (HelpItem) known_entries.get(parent_index);
		    // Otherwise append ".0" and search again...
		    if(parent_item == null) {
			parent_item = (HelpItem) known_entries.get(parent_index + ".0");
		    }
		    // Otherwise the parent item must be the root.
		    if(parent_item == null) {
			parent_item = (HelpItem) root;
		    }
		    // Filename has - instead of .
		    String file_name = index_str.replace('.', '-');
		    // Create the new item
		    HelpItem item;
		    File temp_file = new File(Utility.HELP_DIR + file_name + ".xml");
		    if(temp_file.exists()) {
			item = new HelpItem(index_str + " " + title, Utility.HELP_DIR + file_name + ".xml");
		    }
		    else {
			item = new HelpItem(index_str + " " + title, Utility.HELP_DIR + file_name + ".htm");
		    }
		    temp_file = null;
		    // Insert into parent
		    insertNodeInto(item, parent_item, parent_item.getChildCount());
		    // Record in known entries
		    known_entries.put(index_str, item);
		    item = null;
		    file_name = null;
		    parent_item = null;
		    parent_index = null;
		}
		title = null;
		index_str = null;
		tokenizer = null;
	    }
	    known_entries.clear();
	    known_entries = null;
	    line = null;
	    buffered_reader.close();
	    buffered_reader = null;
	    file_reader.close();
	    file_reader = null;
	}
	catch (Exception error) {
	    Gatherer.println("Cannot build help contents. Possible error in index.txt");
	    Gatherer.printStackTrace(error);
	}
    }
}
