<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
  extension-element-prefixes="java util"
  exclude-result-prefixes="java util">

  <xsl:include href="style.xsl"/>
  <xsl:include href="service-params.xsl"/>
  <xsl:output method="html"/>
  <!--
  <xsl:output method="xml"/>
  -->

  <xsl:template name="pageHead">
    <xsl:variable name="docID" select="/page/pageResponse/document/@selectedNode"/>
    <head>
      <title><xsl:for-each select='/page/pageResponse/document/descendant::documentNode[@nodeID=$docID]/ancestor-or-self::documentNode'><xsl:if test='position()!=1'>::</xsl:if><xsl:value-of select="metadataList/metadata[@name='Title']"/></xsl:for-each></title>
      <xsl:call-template name="css-style"/>
    </head>
  </xsl:template>

  <!-- this is hard coded for GATE, should somehow do it dynamically-->
  <xsl:template name="css-style">
    <style type="text/css">
      <xsl:text disable-output-escaping="yes">
	span.Location {  display:inline; color : red }
	span.Person {  display:inline; color : green }
	span.Organization {  display:inline; color : yellow }
	span.Date {  display:inline; color : blue }
	span.query_term {display: inline; background-color : yellow }
      </xsl:text>
    </style>
  </xsl:template>
  
  <xsl:template match="pageResponse">
    <xsl:variable name="collName"><xsl:value-of select="/page/pageRequest/paramList/param[@name='c']/@value"/></xsl:variable>
    <center>
      <xsl:call-template name="collectionPageBanner">
	<xsl:with-param name="collName" select="$collName"/>
      </xsl:call-template>
      
      <!-- display the document -->
      <xsl:apply-templates select="document">
	<xsl:with-param name="collName" select="$collName"/>
      </xsl:apply-templates>
    </center>
    
    <xsl:call-template name="greenBar"/>
  </xsl:template>
	
  <xsl:template match="document">
    <xsl:param name="collName"/>
    <p/>
    <xsl:call-template name="documentHeading">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
    <p/>
    <xsl:call-template name="documentContent">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
  </xsl:template>

  <!-- hierarchical document -->
  <xsl:template name="documentHeading">
    <xsl:param name="collName"/>
    <table width="537" cellpadding="0" cellspacing="0">
      <tr>
	<td valign="top" align="left" width="200">
	  <xsl:call-template name="coverImage"/>
	  <p/>
	  <xsl:call-template name="enrichServices">
	    <xsl:with-param name="collName" select="$collName"/>
	  </xsl:call-template>
	</td>
	<td valign="top">
	  <xsl:call-template name="TOC">
	    <xsl:with-param name="collName" select="$collName"/>
	  </xsl:call-template>
	</td>
      </tr>
    </table>
  </xsl:template>

  <xsl:template name="coverImage">
    <img><xsl:attribute name='src'><xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>/index/assoc/<xsl:value-of select="metadataList/metadata[@name='archivedir']"/>/cover.jpg</xsl:attribute></img>
  </xsl:template>

  <xsl:template name="TOC">
    <xsl:param name="collName"/>
    <xsl:choose>
      <xsl:when test="@documentType='hierarchy'">
	<xsl:call-template name="hierarchicalContents">
	  <xsl:with-param name="collName" select="$collName"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="@documentType='paged'">
	<xsl:call-template name="pagedContents">
	  <xsl:with-param name="collName" select="$collName"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
	<!-- just print the title of teh one and only docNode -->
	<xsl:value-of select="documentNode/metadataList/metadata[@name='Title']"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="hierarchicalContents">
    <xsl:param name="collName"/>
    <xsl:apply-templates select="documentNode[@nodeID]">
      <xsl:with-param name="collName" select="$collName"/>
      <xsl:with-param name="depth" select="0"/>
    </xsl:apply-templates>
  </xsl:template>
  
  <xsl:template match="documentNode">
    <xsl:param name="collName"/>
    <xsl:param name="depth"/>
    <xsl:variable name="space" select="$depth * 25"/>
    
    <table>
      <tr valign="top">
	<td>
	  <xsl:if test="not($depth = '0')">
	    <img src="interfaces/default/images/space.gif" width="{$space}"/>
	  </xsl:if>
	</td>
	
	<!-- Display the appropriate image, depending on the node type -->
	<td valign="top">
	  <a><xsl:attribute name="href"><xsl:value-of select='$library_name'/>?a=d&amp;c=<xsl:value-of select='$collName'/>&amp;d=<xsl:value-of select='@nodeID'/><xsl:if test="documentNode">.pr</xsl:if><xsl:if test="@nodeType='leaf'">&amp;sib=1</xsl:if></xsl:attribute>
	    <xsl:apply-templates select="." mode="displayNodeIcon"/>
	  </a>
	</td>
	
	<!-- Display associated title, bolded if the node has content -->
	<td valign="top">
	  <xsl:choose>
	    <xsl:when test="nodeContent">
	      <b><xsl:value-of select="metadataList/metadata[@name='Title']"/></b>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="metadataList/metadata[@name='Title']"/>
	    </xsl:otherwise>
	  </xsl:choose>
	</td>
      </tr>
    </table>    
    <!-- Apply recursively to the children of this node -->
    <xsl:apply-templates select="documentNode[@nodeID]">
      <xsl:with-param name="collName" select="$collName"/>
      <xsl:with-param name="depth" select="$depth + 1"/>
    </xsl:apply-templates>
  </xsl:template>
  

  <!-- default content is to process any nodeContent elements and print out their text -->
  <xsl:template name="documentContent">
    <xsl:apply-templates select="descendant::documentNode/nodeContent"/>
  </xsl:template>
  

  <!-- the actual text/content -->
  <xsl:template match="nodeContent">
    <p/>
    <table width="537" cellpadding="0" cellspacing="0">
      <tr>
	<td align="left">
	  <xsl:for-each select="node()">
	    <xsl:choose>
	      <xsl:when test="not(name())"><xsl:value-of select="." disable-output-escaping="yes"/></xsl:when>
	      <xsl:otherwise><xsl:apply-templates select="."/></xsl:otherwise>
	    </xsl:choose>
	  </xsl:for-each>
	</td>
      </tr>
    </table>
  </xsl:template>

  <!-- match any annotations and make them span elements -->
  <xsl:template match="annotation">
    <span class="{@type}"><xsl:value-of disable-output-escaping="yes" select="."/></span>
  </xsl:template>


 
  <!-- paged naviagtion : INCOMPLETE!!-->
  <xsl:template name="pagedContents">
    <xsl:param name="collName"/>
    <xsl:variable name="pos" select="nodeStructureInfo/info[@name='siblingPosition']/@value"/>
    <xsl:variable name="length" select="nodeStructureInfo/info[@name='numSiblings']/@value"/>
    <xsl:variable name="children" select="nodeStructureInfo/info[@name='numChildren']/@value"/>
    <table>
      <xsl:choose>
	<xsl:when test="$pos=-1"><!-- a doc -->
	  <tr valign="top">
	    <td align="left">
	    </td>
	    <td align="center"><center>
		<b><xsl:value-of select="$children"/> pages.</b>
	      </center></td>
	    <td align="right">
	      <a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.fc"><img src="interfaces/nzdl/images/more.gif" border="0" align="absbottom" /></a>
	    </td>
	  </tr>
	</xsl:when>
	
	<xsl:otherwise> <!-- an internal node -->	  
	  <tr valign="top">
	    <td align="left">
	      <xsl:if test=" not ( $pos = 1 )">
		<a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.ps"><img src="interfaces/nzdl/images/less.gif" border="0" align="absbottom" /></a>
	      </xsl:if>
	    </td>
	    <td align="center"><center>
		<b>Page <xsl:value-of select="$pos"/> of <xsl:value-of select="$length"/>.</b>
	      </center></td>
	    <td align="right">
	      <xsl:if test=" not($pos = $length)">
		<a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.ns"><img src="interfaces/nzdl/images/more.gif" border="0" align="absbottom" /></a>
	      </xsl:if>
	    </td>
	  </tr>
	</xsl:otherwise>
      </xsl:choose>
      <tr valign="middle">
	<td align='center' valign='top' colspan='3'> goto form
	</td>
      </tr>
    </table>
  </xsl:template>
  
  <xsl:template name="enrichServices">
    <xsl:param name="collName"/>
    <xsl:variable name="docID" select="/page/pageRequest/paramList/param[@name='d']/@value"/>
    <xsl:for-each select="../serviceList/service">
      <table border='1' cellspacing='0'>
	<tr><td>
	    <p /><xsl:value-of select="display/name"/><p/>
	    <form name="EnrichForm" method="get" action="/gsdl3/{$library_name}">
	      <xsl:apply-templates select="paramList"/>
	      <input type='hidden' name='a' value='d'/>
	      <input type='hidden' name='d' value='{$docID}'/>
	      <input type='hidden' name='c' value='{$collName}'/>
	      <xsl:if test='/page/pageRequest/paramList/param[@name="sib"]'>
		<input type='hidden' name='sib'><xsl:attribute name='value'><xsl:value-of select='/page/pageRequest/paramList/param[@name="sib"]/@value'/></xsl:attribute></input></xsl:if>
	      <input type='hidden' name='s' value='{@name}'/>
	      <input type="submit"><xsl:attribute name="value"><xsl:value-of select='display/submit'/></xsl:attribute></input>
	    </form>
	  </td></tr>
      </table>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="paramList" mode="hidden">
    <xsl:for-each select="param">
      <input type='hidden' name='{@name}' value='{@value}'/><xsl:text>
      </xsl:text>
    </xsl:for-each>
  </xsl:template>
  
  <xsl:template match="paramList">
    <p/><table>
      <xsl:for-each select="param">
	<xsl:choose>
	  <xsl:when test="@type='multi'">
	    <tr><td colspan='2'>
		<xsl:apply-templates select='.'/></td></tr>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:variable name="pname" select="@name"/>
	    <tr><td><xsl:value-of select='ancestor::service/display/param[@name=$pname]/name'/></td><td align="right"><xsl:apply-templates select="."/></td></tr>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:for-each>
    </table>
  </xsl:template>
  
</xsl:stylesheet>




