<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
  extension-element-prefixes="java util"
  exclude-result-prefixes="java util">
  
  <!-- some global parameters - these are set by whoever is invoking the transformation -->
  <xsl:param name="interface_name"/>
  <xsl:param name="library_name"/>

  <!-- the main page layout template is here -->
  <xsl:template match="page">
    <html>
      <xsl:call-template name="pageHead"/>
      <body xsl:use-attribute-sets="body-style">
	<table border="0" cellspacing="0" cellpadding="0" width="100%">
	  <td valign="top" width="65">
	    <img src="interfaces/default/images/spacer.gif" width="65" height="1" alt="" border="0"/>
	  </td>
	  <td>
	    <center>
	      <table width="537">
		<tr><td>
		    <xsl:apply-templates select="pageResponse"/>
		    <xsl:call-template name="greenstoneFooter"/>
		  </td></tr>
	      </table>
	    </center>
	  </td>
	</table>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="headScript">
    <script>
      <xsl:text disable-output-escaping="yes">
	&lt;!--
	var loaded = new Array();
	function gbutton (image, onimage) {
	if (image &amp;&amp; image.src &amp;&amp; (image.out == null || typeof(image.out) == typeof(void(0)))) {
	s = image.src;
	image.out = new Image();
	image.out.src = s;
	image.over = new Image();
	image.over.src = onimage;
	loaded[image.name] = image;
	}
	}
      
	function roll (imagename, over) {
	if (document.images) {
	if (over) i = "over";
	else i = "out";
	image = loaded[imagename];
	if (image) image.src = eval("image."+i+".src");
	}
	}
	//--&gt;
     </xsl:text>
     
    </script>
  </xsl:template>

  <xsl:template name="genericPageBanner">
    <xsl:variable name="library" select="/page/pageExtra/config/library_name"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <center>
      <table width="537">
	<tr><td align="left"></td>
	  <td align="right">
	    <a href="{$library_name}?a=p&amp;sa=home" onMouseover="roll('homer',1);" onMouseOut="roll('homer',0);"><img name="homer" src="interfaces/nzdl/images/{$lang}/chomeof.gif" onLoad="gbutton(this, 'interfaces/nzdl/images/{$lang}/chomeon.gif');" border="0" alt="Home page"/></a>
	  </td>
	</tr>
      </table>
    </center>
    <xsl:call-template name="greenBar"/>
  </xsl:template>
  

  <!-- just pass in collname cos use it everywhere - saves working it out lots of times -->
  <xsl:template name="collectionPageBanner">
    <xsl:param name="collName"/>
    <xsl:param name="pageType"/>
    <xsl:variable name="httpPath" select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    <xsl:variable name="colIcon" select="/page/pageResponse/collection/metadataList/metadata[@name='colIcon']"/>
    <xsl:variable name="library" select="/page/pageExtra/config/library_name"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <table width="537">
      <tr>
	<td align="left" rowspan="2">
	  <a href="{$library_name}?a=p&amp;sa=about&amp;c={$collName}">
	    <img border="1" src="{$httpPath}/images/{$colIcon}">
	      <xsl:attribute name="alt">
		<xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'aboutpage')"/>
	      </xsl:attribute>
	    </img>
	  </a>
	</td>
	<td align="right">
	  <a href="{$library_name}?a=p&amp;sa=home" onMouseover="roll('homer',1);" onMouseOut="roll('homer',0);"><img name="homer" src="interfaces/nzdl/images/{$lang}/chomeof.gif" onLoad="gbutton(this, 'interfaces/nzdl/images/{$lang}/chomeon.gif');" border="0" alt="Home page"/></a>
	  <a href="{$library_name}?a=p&amp;sa=help&amp;c={$collName}" onMouseover="roll('help',1);" onMouseOut="roll('help',0);"><img name="help" src="interfaces/nzdl/images/{$lang}/chelpof.gif" onLoad="gbutton(this, 'interfaces/nzdl/images/{$lang}/chelpon.gif');" border="0" alt="Help page"/></a>
	  <a href="{$library_name}?a=p&amp;sa=pref&amp;c={$collName}" onMouseover="roll('pref',1);" onMouseOut="roll('pref',0);"><img name="pref" src="interfaces/nzdl/images/{$lang}/cprefof.gif" onLoad="gbutton(this, 'interfaces/nzdl/images/{$lang}/cprefon.gif');" border="0" alt="Preferences page"/></a>
	</td>
      </tr>
      <tr>
	<td align='right'><xsl:if test="$pageType"><img src="interfaces/nzdl/images/{$lang}/h_{$pageType}.gif"  width="200" height="57"/></xsl:if></td>
      </tr>
      
      <tr>
	<td colspan='2'></td>
      </tr>
    </table>
    
    <xsl:call-template name="navigationBar">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="navigationBar">
    <xsl:param name="collName"/>
    <xsl:variable name="classifiers" select="/page/pageResponse/collection/serviceList/service[@name='ClassifierBrowse']/classifierList"/>
    <xsl:variable name="action" select="/page/pageRequest/@action"/>
    <xsl:variable name="classifier" select="/page/pageRequest/paramList/param[@name='cl']/@value"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <!--action=<xsl:value-of select="$action"/>, classifier=<xsl:value-of select="$classifier"/>-->
    <xsl:text disable-output-escaping='yes'>
      &lt;!-- Navigation Bar --&gt;
    </xsl:text>
    <nobr>
      <xsl:call-template name="nbSearch">
	<xsl:with-param name="collName" select="$collName"/>
	<xsl:with-param name="action" select="$action"/>
      </xsl:call-template>
      
      <xsl:for-each select="$classifiers/classifier">
	<xsl:apply-templates select="." mode="nav-bar-button">
	  <xsl:with-param name="collName" select="$collName"/>
	  <xsl:with-param name="classifier" select="$classifier"/>
	</xsl:apply-templates>
      </xsl:for-each>
      <xsl:call-template name="nbPhrase"> <!-- this may be nothing if there is no phrase browsing for a collection -->
	<xsl:with-param name="collName" select="$collName"/>
	<xsl:with-param name="action" select="$action"/>
      </xsl:call-template>  
    </nobr>
    <xsl:text disable-output-escaping='yes'>
      &lt;!-- End of Navigation Bar --&gt;
    </xsl:text>
  </xsl:template>


  <xsl:template name="navBarImage">
    <xsl:param name="url"/>
    <xsl:param name="name"/>
    <xsl:param name="alt"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <a href="{$url}" onMouseOver="roll('{$name}', 1);" onMouseOut="roll('{$name}', 0);"><img name="{$name}" src="interfaces/nzdl/images/{$lang}/t{$name}of.gif" onLoad="gbutton(this,'interfaces/nzdl/images/{$lang}/t{$name}on.gif');" border='0' alt="{$alt}" title="{alt}"/></a>
  </xsl:template>
  
  <xsl:template name="nbSearch">
    <xsl:param name="collName"/>
    <xsl:param name="action"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <xsl:choose>
      <xsl:when test="$action='q'">
	<img src="interfaces/nzdl/images/{$lang}/tSearchgr.gif" border='0' alt="Search" title="Search"/>
      </xsl:when>
      <xsl:otherwise>
	<!-- need to check for form search -->
	<xsl:variable name="query-service">
	  <xsl:choose>
	    <xsl:when test="not(/page/pageRequest/paramList/param[@name='ct'])">TextQuery</xsl:when>
	    <xsl:when test="/page/pageRequest/paramList/param[@name='ct']/@value='0'">TextQuery</xsl:when>
	    <xsl:when test="/page/pageRequest/paramList/param[@name='qt']/@value='0'">TextQuery</xsl:when>
	    <xsl:when test="/page/pageRequest/paramList/param[@name='qfm']/@value='0'">FieldQuery</xsl:when>
	    <xsl:otherwise>AdvancedFieldQuery</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>
	<xsl:call-template name="navBarImage">
	  <xsl:with-param name="url">nzdl?a=q&amp;rt=d&amp;s=<xsl:value-of select="$query-service"/>&amp;c=<xsl:value-of select="$collName"/></xsl:with-param>
	  <xsl:with-param name="name">Search</xsl:with-param>
	  <xsl:with-param name="alt">Search</xsl:with-param>
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="nbPhrase">
    <xsl:param name="collName"/>
    <xsl:param name="action"/>
    <xsl:variable name="lang" select="/page/@lang"/>
    <xsl:if test="/page/pageResponse/collection/serviceList/service[@name='PhindApplet']">
      <xsl:choose>
	<xsl:when test="$action='a'"><!-- note, this assumes that the phind applet is the only applet -->
	  <img src="interfaces/nzdl/images/{$lang}/tPhrasegr.gif" border='0' alt="Phrase Browse" title="Phrase Browse"/>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:call-template name="navBarImage">
	    <xsl:with-param name="url">nzdl?a=a&amp;rt=d&amp;s=PhindApplet&amp;c=<xsl:value-of select="$collName"/></xsl:with-param>
	    <xsl:with-param name="name">Phrase</xsl:with-param>
	    <xsl:with-param name="alt">Phrase Browse</xsl:with-param>
	  </xsl:call-template>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  
  <xsl:template match="classifier" mode="nav-bar-button">
    <xsl:param name="collName"/>
    <xsl:param name="classifier"/>
    <xsl:variable name="buttonname"><xsl:choose><xsl:when test="@buttonname"><xsl:value-of select="@buttonname"/></xsl:when><xsl:otherwise><xsl:value-of select="@content"/></xsl:otherwise></xsl:choose></xsl:variable>
    <xsl:variable name="lang" select="/page/@lang"/>
    <xsl:choose>
      <xsl:when test="$classifier=@name">
	<img src="interfaces/nzdl/images/{$lang}/t{$buttonname}gr.gif" border='0' alt="{$buttonname}" title="{$buttonname}"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="navBarImage">
	  <xsl:with-param name="url">nzdl?a=b&amp;rt=r&amp;s=ClassifierBrowse&amp;c=<xsl:value-of select="$collName"/>&amp;cl=<xsl:value-of select="@name"/></xsl:with-param>
	  <xsl:with-param name="name" select="$buttonname"/>
	  <xsl:with-param name="alt" select="$buttonname"/>
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
    
  <!-- do we want different stuff for cluster or same as collection -->
  <xsl:template name="clusterPageBanner">
    <xsl:param name="clusterName"/>
    <xsl:variable name="library" select="/page/pageExtra/config/library_name"/>
    <table width="537">
      <tr><td align="left"><a href="{$library_name}?a=p&amp;sa=about&amp;c={$clusterName}"><xsl:value-of select="$clusterName"/></a></td><td align="right"><a href="{$library_name}?a=p&amp;sa=home"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'home')"/></a></td></tr></table>
    
    <xsl:call-template name="greenBar"/>
  </xsl:template>
 

  <xsl:attribute-set name="body-style">
    <xsl:attribute name="bgcolor">#ffffff</xsl:attribute>
    <xsl:attribute name="text">#000000</xsl:attribute>
    <xsl:attribute name="link">#006666</xsl:attribute>
    <xsl:attribute name="alink">#cc9900</xsl:attribute>
    <xsl:attribute name="vlink">#666633</xsl:attribute>
    <xsl:attribute name="background">interfaces/default/images/chalk.gif</xsl:attribute>
  </xsl:attribute-set>
    
  <!-- this should probably use a greenstone image rather than nzdl image -->
  <xsl:template name="nzdlPageBanner">
    <center>
      <table width="537" cellspacing="0" cellpadding="0">
	<tr valign="top">
	  <td rowspan="2" align="left"><center><img src="interfaces/nzdl/images/nzdl2gr.gif" width="457" height="181" ><xsl:attribute name="alt"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'nzdl')"/></xsl:attribute></img></center></td>
	  <td align="right"></td>
	</tr>
	
	<tr>
	  <td align="right"></td>
	</tr>
	
	<tr>
	  <td colspan="2"></td>
	</tr>
      </table>
    </center>
    
    <!-- end of page banner -->
    
  </xsl:template>

  <xsl:template name="greenstoneFooter">
    <center>
      <p/>
      <small>powered by greenstone3</small>
    </center>
  </xsl:template>
  
  
  <xsl:template name="greenBar">
    <p/><img src="interfaces/default/images/divb.gif" width="537" height="17"/>
  </xsl:template>
  
  <xsl:template name="iconblankbar">
    <p/><img src="interfaces/default/images/divb.gif" width="537" height="17"/>
  </xsl:template>
  
  <xsl:template name="imagegreenstone">
    <img src="interfaces/nzdl/images/gsdl.gif" width="140" height="77" border="0" hspace='0'><xsl:attribute name='alt'><xsl:call-template name='textimagegreenstone'/></xsl:attribute></img>
  </xsl:template>
  

  <!-- Display the appropriate image, depending on the node type -->
  <xsl:template match="documentNode" mode="displayNodeIcon">
    
  <!-- Root node: book icon (open or closed) -->
  <xsl:if test="@nodeType='root'">
    <xsl:choose>
      <xsl:when test="documentNode">
	<img border="0" width="28" height="23"
	     src="interfaces/default/images/openbook.gif"
	     alt="Close this book"/>
      </xsl:when>
      <xsl:otherwise>
	<img border="0" width="18" height="11"
	     src="interfaces/default/images/book.gif"
	     alt="Open this document and view contents"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>

  <!-- Interior node: folder icon (open or closed) -->
  <xsl:if test="@nodeType='interior'">
    <xsl:choose>
      <xsl:when test="documentNode">
	<img border="0" width="23" height="15"
	     src="interfaces/default/images/openfldr.gif"
	     alt="Close this folder"/>
      </xsl:when>
      <xsl:otherwise>
	<img border="0" width="23" height="15"
	     src="interfaces/default/images/clsdfldr.gif"
	     alt="Open this folder and view contents"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>

  <!-- Leaf node: page icon -->
  <xsl:if test="@nodeType='leaf'">
    <img border="0" width="16" height="21"
	 src="interfaces/default/images/itext.gif"
	 alt="View the document"/>
  </xsl:if>
</xsl:template>


</xsl:stylesheet>  
